@@ -4,7 +4,7 @@
 #'   or endyear of the decennial Census or ACS sample. 5-year ACS data is
 #'   available from 2009 through 2020. 1-year ACS data is available from 2005
 #'   through 2021, with the exception of 2020.
-#' @param dataset One of "sf1", "sf2", "sf3", "sf4", "pl",
+#' @param dataset One of "sf1", "sf2", "sf3", "sf4", "pl", "dhc", "dp",
 #'   "as", "gu", "mp", "vi", "acsse", "acs1", "acs3", "acs5", "acs1/profile",
 #'   "acs3/profile", "acs5/profile", "acs1/subject", "acs3/subject", "acs5/subject",
 #'   "acs1/cprofile", or "acs5/cprofile".
@@ -20,7 +20,7 @@
 #'
 load_variables <- function(
   year,
-  dataset = c("sf1", "sf2", "sf3", "sf4", "pl",
+  dataset = c("sf1", "sf2", "sf3", "sf4", "pl", "dhc", "dp",
               "as", "gu", "mp", "vi", "acsse",
               "dpas", "dpgu", "dpmp", "dpvi",
               "acs1", "acs3", "acs5", "acs1/profile",
@@ -73,7 +73,7 @@ load_variables <- function(
   }
 
   if (dataset %in% c("sf1", "sf2", "sf3", "sf4", "pl",
-                     "as", "gu", "mp", "vi",
+                     "as", "gu", "mp", "vi", "dhc", "dp",
                      "dpas", "dpgu", "dpmp", "dpvi")) {
     dataset <- paste0("dec/", dataset)
   }
